@@ -1,32 +1,37 @@
-# SPDX-FileCopyrightText: 2020 2020
 #
-# SPDX-License-Identifier: Apache-2.0
+# Copyright 2021 Splunk Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
 
 """UCC Config Module
 This is for load/save configuration in UCC server or TA.
 The load/save action is based on specified schema.
 """
 
-from __future__ import absolute_import
 
-from future import standard_library
-
-standard_library.install_aliases()
-import sys
-from builtins import object
 import json
 import logging
-import traceback
 import time
+import traceback
+from urllib.parse import quote
 
-from splunktalib.rest import splunkd_request, code_to_msg
 from splunktalib.common import util as sc_util
+from splunktalib.rest import code_to_msg, splunkd_request
 
 import splunktaucclib.common.log as stulog
 from splunktaucclib.common import UCCException
-from urllib.parse import quote
 
-basestring = str if sys.version_info[0] == 3 else basestring
 LOGGING_STOPPED = False
 
 
@@ -54,10 +59,10 @@ def log(msg, msgx="", level=logging.INFO, need_tb=False):
         return
 
     msgx = " - " + msgx if msgx else ""
-    content = "UCC Config Module: %s%s" % (msg, msgx)
+    content = f"UCC Config Module: {msg}{msgx}"
     if need_tb:
         stack = "".join(traceback.format_stack())
-        content = "%s\r\n%s" % (content, stack)
+        content = f"{content}\r\n{stack}"
     stulog.logger.log(level, content, exc_info=1)
 
 
@@ -67,7 +72,7 @@ class ConfigException(UCCException):
     pass
 
 
-class Config(object):
+class Config:
     """UCC Config Module"""
 
     # Placeholder stands for any field
@@ -308,7 +313,7 @@ class Config(object):
         )
         for field in Config.META_FIELDS:
             assert field in ucc_config_schema and isinstance(
-                ucc_config_schema[field], basestring
+                ucc_config_schema[field], str
             ), ('Missing or invalid field "%s" in given schema' % field)
             setattr(self, field, ucc_config_schema[field])
 
