@@ -1,19 +1,28 @@
-# SPDX-FileCopyrightText: 2020 2020
 #
-# SPDX-License-Identifier: Apache-2.0
+# Copyright 2021 Splunk Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
 
-from __future__ import absolute_import
 
-from builtins import object
 import copy
 import json
 from multiprocessing.pool import ThreadPool
 
 from splunklib.binding import HTTPError
 
-from ..rest_handler.schema import RestSchema
 from ..rest_handler.handler import RestHandler
-
+from ..rest_handler.schema import RestSchema
 
 __all__ = [
     "GlobalConfigError",
@@ -28,15 +37,15 @@ class GlobalConfigError(Exception):
     pass
 
 
-class Configuration(object):
+class Configuration:
     """
     Splunk Configuration Handler.
     """
 
-    FILTERS = [u"eai:appName", u"eai:acl", u"eai:userName"]
-    ENTITY_NAME = u"name"
-    SETTINGS = u"settings"
-    NOT_FOUND = u"[404]: Not Found"
+    FILTERS = ["eai:appName", "eai:acl", "eai:userName"]
+    ENTITY_NAME = "name"
+    SETTINGS = "settings"
+    NOT_FOUND = "[404]: Not Found"
 
     def __init__(self, splunkd_client, schema):
         """
@@ -242,7 +251,7 @@ class Configuration(object):
 
 class Inputs(Configuration):
     def __init__(self, splunkd_client, schema):
-        super(Inputs, self).__init__(splunkd_client, schema)
+        super().__init__(splunkd_client, schema)
         self._splunkd_client = splunkd_client
         self._schema = schema
         self._references = None
@@ -346,7 +355,7 @@ class Configs(Configuration):
 
 class Settings(Configuration):
 
-    TYPE_NAME = u"settings"
+    TYPE_NAME = "settings"
 
     def load(self):
         """
@@ -374,7 +383,7 @@ class Settings(Configuration):
         return self._schema.settings
 
     def _search_configuration_schema(self, type_name, configuration_name):
-        return super(Settings, self)._search_configuration_schema(
+        return super()._search_configuration_schema(
             configuration_name,
             configuration_name,
         )
