@@ -1,19 +1,30 @@
+#
+# Copyright 2021 Splunk Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
 
-from __future__ import absolute_import
 
+import os
 from functools import wraps
-from splunk import admin
+
 from solnlib.splunkenv import get_splunkd_uri
 from solnlib.utils import is_true
+from splunk import admin
 
 from .eai import EAI_FIELDS
+from .endpoint import DataInputModel, MultipleModel, SingleModel
 from .handler import RestHandler
-import os
-from .endpoint import (
-    SingleModel,
-    DataInputModel,
-    MultipleModel
-)
 
 try:
     from custom_hook_mixin import CustomHookMixin as HookMixin
@@ -22,9 +33,9 @@ except ImportError:
 
 
 __all__ = [
-    'make_conf_item',
-    'build_conf_info',
-    'AdminExternalHandler',
+    "make_conf_item",
+    "build_conf_info",
+    "AdminExternalHandler",
 ]
 
 
@@ -45,6 +56,7 @@ def build_conf_info(meth):
     :param meth:
     :return:
     """
+
     @wraps(meth)
     def wrapper(self, confInfo):
         result = meth(self, confInfo)
@@ -57,31 +69,28 @@ def build_conf_info(meth):
 
     return wrapper
 
+
 def get_splunkd_endpoint():
-    if os.environ.get('SPLUNKD_URI'):
-        return os.environ['SPLUNKD_URI']
+    if os.environ.get("SPLUNKD_URI"):
+        return os.environ["SPLUNKD_URI"]
     else:
         splunkd_uri = get_splunkd_uri()
-        os.environ['SPLUNKD_URI'] = splunkd_uri
+        os.environ["SPLUNKD_URI"] = splunkd_uri
         return splunkd_uri
 
 
-class AdminExternalHandler(HookMixin, admin.MConfigHandler, object):
+class AdminExternalHandler(HookMixin, admin.MConfigHandler):
 
     # Leave it for setting REST model
     endpoint = None
 
     # action parameter for getting clear credentials
-    ACTION_CRED = '--cred--'
+    ACTION_CRED = "--cred--"
 
     def __init__(self, *args, **kwargs):
         # use classic inheritance to be compatible for
         # old version of Splunk private SDK
-        admin.MConfigHandler.__init__(
-            self,
-            *args,
-            **kwargs
-        )
+        admin.MConfigHandler.__init__(self, *args, **kwargs)
         self.handler = RestHandler(
             get_splunkd_endpoint(),
             self.getSessionKey(),
@@ -135,7 +144,7 @@ class AdminExternalHandler(HookMixin, admin.MConfigHandler, object):
             session_key=self.getSessionKey(),
             config_name=self._get_name(),
             stanza_id=self.callerArgs.id,
-            payload=self.payload
+            payload=self.payload,
         )
         return self.handler.create(
             self.callerArgs.id,
@@ -144,13 +153,13 @@ class AdminExternalHandler(HookMixin, admin.MConfigHandler, object):
 
     @build_conf_info
     def handleEdit(self, confInfo):
-        disabled = self.payload.get('disabled')
+        disabled = self.payload.get("disabled")
         if disabled is None:
             self.edit_hook(
                 session_key=self.getSessionKey(),
                 config_name=self._get_name(),
                 stanza_id=self.callerArgs.id,
-                payload=self.payload
+                payload=self.payload,
             )
             return self.handler.update(
                 self.callerArgs.id,
@@ -166,7 +175,7 @@ class AdminExternalHandler(HookMixin, admin.MConfigHandler, object):
         self.delete_hook(
             session_key=self.getSessionKey(),
             config_name=self._get_name(),
-            stanza_id=self.callerArgs.id
+            stanza_id=self.callerArgs.id,
         )
         return self.handler.delete(self.callerArgs.id)
 
@@ -188,14 +197,14 @@ class AdminExternalHandler(HookMixin, admin.MConfigHandler, object):
 
         payload = {}
         for filed, value in self.callerArgs.data.items():
-            payload[filed] = value[0] if value and value[0] else ''
+            payload[filed] = value[0] if value and value[0] else ""
         return payload
 
 
 def handle(
-        endpoint,
-        handler=AdminExternalHandler,
-        context_info=admin.CONTEXT_APP_ONLY,
+    endpoint,
+    handler=AdminExternalHandler,
+    context_info=admin.CONTEXT_APP_ONLY,
 ):
     """
     Handle request.
@@ -207,7 +216,7 @@ def handle(
     """
     real_handler = type(
         handler.__name__,
-        (handler, ),
-        {'endpoint': endpoint},
+        (handler,),
+        {"endpoint": endpoint},
     )
     admin.init(real_handler, ctxInfo=context_info)
