@@ -36,7 +36,6 @@ from splunktaucclib.rest_handler.util import makeConfItem
 
 __all__ = ["user_caps", "BaseRestHandler", "BaseModel", "ResourceHandler"]
 
-basestring = str if sys.version_info[0] == 3 else basestring
 APP_NAME = sc_util.get_appname_from_path(op.abspath(__file__))
 
 
@@ -128,9 +127,7 @@ class BaseRestHandler(admin.MConfigHandler):
             except ResourceNotFound:
                 self.exist4sync = False
             except Exception as exc:
-                RH_Err.ctl(
-                    1102, msgx="object={}, err={}".format(self.callerArgs.id, exc)
-                )
+                RH_Err.ctl(1102, msgx=f"object={self.callerArgs.id}, err={exc}")
             else:
                 self.exist4sync = True
         self._cred_mgmt = self.get_cred_mgmt(self.endpoint)
@@ -397,7 +394,7 @@ class BaseRestHandler(admin.MConfigHandler):
             except ResourceNotFound:
                 RH_Err.ctl(
                     1021,
-                    msgx="endpoint={}, item={}".format(self.endpoint, name),
+                    msgx=f"endpoint={self.endpoint}, item={name}",
                     shouldPrint=False,
                     shouldRaise=False,
                 )
@@ -695,9 +692,7 @@ class BaseModel:
                 if not self.validators[k].validate(v, args):
                     RH_Err.ctl(
                         1100,
-                        msgx=(
-                            "{msg} - field={k}".format(msg=self.validators[k].msg, k=k)
-                        ),
+                        msgx=(f"{self.validators[k].msg} - field={k}"),
                         logLevel=logging.INFO,
                     )
         return args
@@ -709,7 +704,7 @@ class BaseModel:
                 continue
             if isinstance(vs, list) or isinstance(vs, dict) or isinstance(vs, tuple):
                 data[k] = [
-                    self.normalisers[k].normalize(v) if isinstance(v, basestring) else v
+                    self.normalisers[k].normalize(v) if isinstance(v, str) else v
                     for v in vs
                 ]
             else:
