@@ -1,24 +1,36 @@
+#
+# Copyright 2021 Splunk Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
+
 """Credential Management for REST Endpoint
 """
 
-from __future__ import absolute_import
 
-from builtins import object
 import json
 
 import splunk
 from splunk import rest
-
-from .util import getBaseAppName
-from .error_ctl import RestHandlerError
-
 from splunktalib.credentials import CredentialManager as CredMgr
 
+from .error_ctl import RestHandlerError
+from .util import getBaseAppName
 
-__all__ = ['CredMgmt']
+__all__ = ["CredMgmt"]
 
 
-class CredMgmt(object):
+class CredMgmt:
     """Credential Management stored in app.conf
 
     Note: Override it if customized form of ``realm``, ``username``,
@@ -50,11 +62,11 @@ class CredMgmt(object):
             for decrypt & delete.
         :return: a tuple (realm, username, password)
         """
-        realm = CredMgmt.REALM_TEMPLATE.format(baseApp=getBaseAppName(),
-                                               endpoint=self._endpoint,
-                                               stanzaName=stanzaName)
-        username = 'username'
-        password = '' if data is None else json.dumps(data)
+        realm = CredMgmt.REALM_TEMPLATE.format(
+            baseApp=getBaseAppName(), endpoint=self._endpoint, stanzaName=stanzaName
+        )
+        username = "username"
+        password = "" if data is None else json.dumps(data)
         return realm, username, password
 
     def encrypt(self, stanzaName, data):
@@ -65,10 +77,11 @@ class CredMgmt(object):
         :param data: data to encrypt, a dict.
         :return:
         """
-        cred_data_new = {key: ('' if val is None else val)
-                         for key, val in data.items()
-                         if key in self._encryptedArgs and
-                         val != CredMgmt.PASSWORD_MASK}
+        cred_data_new = {
+            key: ("" if val is None else val)
+            for key, val in data.items()
+            if key in self._encryptedArgs and val != CredMgmt.PASSWORD_MASK
+        }
         if not cred_data_new:
             return data
 
@@ -78,13 +91,14 @@ class CredMgmt(object):
             cred_data = {}
 
         cred_data.update(cred_data_new)
-        realm, username, password = self.context(stanzaName,
-                                                 data=cred_data)
-        cred_mgr = CredMgr(self._splunkMgmtUri,
-                           self._sessionKey,
-                           app=self._app,
-                           owner=self._user,
-                           realm=realm)
+        realm, username, password = self.context(stanzaName, data=cred_data)
+        cred_mgr = CredMgr(
+            self._splunkMgmtUri,
+            self._sessionKey,
+            app=self._app,
+            owner=self._user,
+            realm=realm,
+        )
         try:
             # since the size of the to-be-encrypted data is not fixed,
             # if the new data have smaller size than the previous one,
@@ -96,10 +110,7 @@ class CredMgmt(object):
                 if arg in self._encryptedArgs:
                     data[arg] = CredMgmt.PASSWORD_MASK
         except Exception as exc:
-            RestHandlerError.ctl(1020,
-                                 msgx=exc,
-                                 shouldPrint=False,
-                                 shouldRaise=False)
+            RestHandlerError.ctl(1020, msgx=exc, shouldPrint=False, shouldRaise=False)
         return data
 
     def decrypt(self, stanzaName, data):
@@ -114,23 +125,22 @@ class CredMgmt(object):
         if not self._encryptedArgs:
             return data
         realm, username, password = self.context(stanzaName)
-        cred_mgr = CredMgr(self._splunkMgmtUri,
-                           self._sessionKey,
-                           app=self._app,
-                           owner=self._user,
-                           realm=realm)
+        cred_mgr = CredMgr(
+            self._splunkMgmtUri,
+            self._sessionKey,
+            app=self._app,
+            owner=self._user,
+            realm=realm,
+        )
 
         try:
             creds = cred_mgr.get_clear_password(username)
         except Exception as exc:
-            RestHandlerError.ctl(1021,
-                                 msgx=exc,
-                                 shouldPrint=True,
-                                 shouldRaise=True)
+            RestHandlerError.ctl(1021, msgx=exc, shouldPrint=True, shouldRaise=True)
         cred = creds.get(username, {})
 
         for arg, val in list(cred.items()):
-            data[arg] = (val if arg in self._encryptedArgs else data[arg])
+            data[arg] = val if arg in self._encryptedArgs else data[arg]
         return data
 
     def delete(self, stanzaName):
@@ -144,18 +154,17 @@ class CredMgmt(object):
             return
 
         realm, username, password = self.context(stanzaName)
-        cred_mgr = CredMgr(self._splunkMgmtUri,
-                           self._sessionKey,
-                           app=self._app,
-                           owner=self._user,
-                           realm=realm)
+        cred_mgr = CredMgr(
+            self._splunkMgmtUri,
+            self._sessionKey,
+            app=self._app,
+            owner=self._user,
+            realm=realm,
+        )
         try:
             cred_mgr.delete(username, throw=True)
         except Exception as exc:
-            RestHandlerError.ctl(1022,
-                                 msgx=exc,
-                                 shouldPrint=False,
-                                 shouldRaise=False)
+            RestHandlerError.ctl(1022, msgx=exc, shouldPrint=False, shouldRaise=False)
             return False
         return True
 
